==> surveyplat-proof-common-nfzd-1.0.0-20200930.123212-7-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzXmxx.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2019/9/10
 * @description 增减挂钩项目信息表
 */
@Table(name = "dcjz_xmxx")
public class DcjzXmxx {
    //项目ID
    @Id
    private String xmid;
    //项目编号
    private String xmbh;
    //项目名称
    private String xmmc;
    //行政区代码
    private String xzqdm;
    //行政区名称
    private String xzqmc;
    //验收编号
    private String ysbh;
    //地块个数
    private Integer dkgs;
    //应举证地块个数
    private Integer yjzdkgs;
    //验收文号
    private String yswh;
    //验收时间
    private Date yssj;
    //项目建设规模
    private Float xmjsgm;
    //新增耕地面积
    private Float xzgdmj;
    //项目总资金
    private Float xmzzj;
    //项目范围
    private String xmqfw;

    //项目举证状态
    private String xmjzzt;
    //是否重新举证
    private String sfcxjz;
    //备注
    private String bz;
    //是否签订管护协议
    private String sfqdghxy;

    //县级项目结论
    private String xjxmjl;
    //省级项目结论
    private String sjxmjl;
    //省级备注
    private String sjbz;
    //项目分发时间
    private Date xmffsj;

    //省级代码
    private String pdm;
    //市级代码
    private String cdm;

    //核实新增耕地面积
    private String xmlx;
    //地类代码
    private String dlbm;
    //地类名称
    private String dlmc;
    //坐落单位代码
    private String zldwdm;
    //坐落单位名称
    private String zldwmc;
    //权属性质
    private String qsxz;

    //是否摸排范围
    private String sfmpfw;
    //非摸排原因
    private String fmpyy;

    private Float jd;
    private Float wd;
    private String dkly;

    //县级核查人
    private String xjhcr;
    //县级核查状态
    private String xjhczt;
    //县级核查时间
    private Date xjhcsj;
    //县级核查意见
    private String xjhcyj;
    //市级核查状态
    private String cjhczt;
    //市级核查人
    private String cjhcr;
    //市级核查时间
    private Date cjhcsj;
    //市级核查意见
    private String cjhcyj;
    //省级核查状态
    private String sjhczt;
    //省级核查人
    private String sjhcr;
    //省级核查时间
    private Date sjhcsj;
    //省级核查意见
    private String sjhcyj;

    //镇级核查人
    private String zjhcr;
    //镇级核查状态
    private String zjhczt;
    //镇级核查时间
    private Date zjhcsj;
    //镇级核查意见
    private String zjhcyj;
    //镇级复查人
    private String zjfcr;
    //镇级复查状态
    private String zjfczt;
    //镇级复查时间
    private Date zjfcsj;
    //镇级复查意见
    private String zjfcyj;
    //县级复查人
    private String xjfcr;
    //县级复查状态
    private String xjfczt;
    //县级复查时间
    private Date xjfcsj;
    //县级复查意见
    private String xjfcyj;
    //市级复查人
    private String cjfcr;
    //市级复查状态
    private String cjfczt;
    //市级复查时间
    private Date cjfcsj;
    //市级复查意见
    private String cjfcyj;
    //省级复查状态
    private String sjfczt;
    //省级复查人
    private String sjfcr;
    //省级复查时间
    private Date sjfcsj;
    //省级复查意见
    private String sjfcyj;
    //镇级核查人签名id
    private String zjhcrqmid;
    //镇级复查人签名id
    private String zjfcrqmid;
    //县级核查人签名id
    private String xjhcrqmid;
    //县级复查人签名id
    private String xjfcrqmid;
    //市级核查人签名id
    private String cjhcrqmid;
    //市级复查人签名id
    private String cjfcrqmid;
    //省级核查人签名id
    private String sjhcrqmid;
    //省级复查人签名id
    private String sjfcrqmid;

    public String getZjhcr() {
        return zjhcr;
    }

    public void setZjhcr(String zjhcr) {
        this.zjhcr = zjhcr;
    }

    public String getZjhczt() {
        return zjhczt;
    }

    public void setZjhczt(String zjhczt) {
        this.zjhczt = zjhczt;
    }

    public Date getZjhcsj() {
        return zjhcsj;
    }

    public void setZjhcsj(Date zjhcsj) {
        this.zjhcsj = zjhcsj;
    }

    public String getZjhcyj() {
        return zjhcyj;
    }

    public void setZjhcyj(String zjhcyj) {
        this.zjhcyj = zjhcyj;
    }

    public String getZjfcr() {
        return zjfcr;
    }

    public void setZjfcr(String zjfcr) {
        this.zjfcr = zjfcr;
    }

    public String getZjfczt() {
        return zjfczt;
    }

    public void setZjfczt(String zjfczt) {
        this.zjfczt = zjfczt;
    }

    public Date getZjfcsj() {
        return zjfcsj;
    }

    public void setZjfcsj(Date zjfcsj) {
        this.zjfcsj = zjfcsj;
    }

    public String getZjfcyj() {
        return zjfcyj;
    }

    public void setZjfcyj(String zjfcyj) {
        this.zjfcyj = zjfcyj;
    }

    public String getXjfcr() {
        return xjfcr;
    }

    public void setXjfcr(String xjfcr) {
        this.xjfcr = xjfcr;
    }

    public String getXjfczt() {
        return xjfczt;
    }

    public void setXjfczt(String xjfczt) {
        this.xjfczt = xjfczt;
    }

    public Date getXjfcsj() {
        return xjfcsj;
    }

    public void setXjfcsj(Date xjfcsj) {
        this.xjfcsj = xjfcsj;
    }

    public String getXjfcyj() {
        return xjfcyj;
    }

    public void setXjfcyj(String xjfcyj) {
        this.xjfcyj = xjfcyj;
    }

    public String getCjfcr() {
        return cjfcr;
    }

    public void setCjfcr(String cjfcr) {
        this.cjfcr = cjfcr;
    }

    public String getCjfczt() {
        return cjfczt;
    }

    public void setCjfczt(String cjfczt) {
        this.cjfczt = cjfczt;
    }

    public Date getCjfcsj() {
        return cjfcsj;
    }

    public void setCjfcsj(Date cjfcsj) {
        this.cjfcsj = cjfcsj;
    }

    public String getCjfcyj() {
        return cjfcyj;
    }

    public void setCjfcyj(String cjfcyj) {
        this.cjfcyj = cjfcyj;
    }

    public String getSjfczt() {
        return sjfczt;
    }

    public void setSjfczt(String sjfczt) {
        this.sjfczt = sjfczt;
    }

    public String getSjfcr() {
        return sjfcr;
    }

    public void setSjfcr(String sjfcr) {
        this.sjfcr = sjfcr;
    }

    public Date getSjfcsj() {
        return sjfcsj;
    }

    public void setSjfcsj(Date sjfcsj) {
        this.sjfcsj = sjfcsj;
    }

    public String getSjfcyj() {
        return sjfcyj;
    }

    public void setSjfcyj(String sjfcyj) {
        this.sjfcyj = sjfcyj;
    }

    public String getZjhcrqmid() {
        return zjhcrqmid;
    }

    public void setZjhcrqmid(String zjhcrqmid) {
        this.zjhcrqmid = zjhcrqmid;
    }

    public String getZjfcrqmid() {
        return zjfcrqmid;
    }

    public void setZjfcrqmid(String zjfcrqmid) {
        this.zjfcrqmid = zjfcrqmid;
    }

    public String getXjhcrqmid() {
        return xjhcrqmid;
    }

    public void setXjhcrqmid(String xjhcrqmid) {
        this.xjhcrqmid = xjhcrqmid;
    }

    public String getXjfcrqmid() {
        return xjfcrqmid;
    }

    public void setXjfcrqmid(String xjfcrqmid) {
        this.xjfcrqmid = xjfcrqmid;
    }

    public String getCjhcrqmid() {
        return cjhcrqmid;
    }

    public void setCjhcrqmid(String cjhcrqmid) {
        this.cjhcrqmid = cjhcrqmid;
    }

    public String getCjfcrqmid() {
        return cjfcrqmid;
    }

    public void setCjfcrqmid(String cjfcrqmid) {
        this.cjfcrqmid = cjfcrqmid;
    }

    public String getSjhcrqmid() {
        return sjhcrqmid;
    }

    public void setSjhcrqmid(String sjhcrqmid) {
        this.sjhcrqmid = sjhcrqmid;
    }

    public String getSjfcrqmid() {
        return sjfcrqmid;
    }

    public void setSjfcrqmid(String sjfcrqmid) {
        this.sjfcrqmid = sjfcrqmid;
    }

    public String getSfmpfw() {
        return sfmpfw;
    }

    public void setSfmpfw(String sfmpfw) {
        this.sfmpfw = sfmpfw;
    }

    public String getFmpyy() {
        return fmpyy;
    }

    public void setFmpyy(String fmpyy) {
        this.fmpyy = fmpyy;
    }

    public String getCjhczt() {
        return cjhczt;
    }

    public void setCjhczt(String cjhczt) {
        this.cjhczt = cjhczt;
    }

    public String getCjhcr() {
        return cjhcr;
    }

    public void setCjhcr(String cjhcr) {
        this.cjhcr = cjhcr;
    }

    public Date getCjhcsj() {
        return cjhcsj;
    }

    public void setCjhcsj(Date cjhcsj) {
        this.cjhcsj = cjhcsj;
    }

    public String getCjhcyj() {
        return cjhcyj;
    }

    public void setCjhcyj(String cjhcyj) {
        this.cjhcyj = cjhcyj;
    }

    public String getXmlx() {
        return xmlx;
    }

    public void setXmlx(String xmlx) {
        this.xmlx = xmlx;
    }

    public String getDlbm() {
        return dlbm;
    }

    public void setDlbm(String dlbm) {
        this.dlbm = dlbm;
    }

    public String getDlmc() {
        return dlmc;
    }

    public void setDlmc(String dlmc) {
        this.dlmc = dlmc;
    }

    public String getZldwdm() {
        return zldwdm;
    }

    public void setZldwdm(String zldwdm) {
        this.zldwdm = zldwdm;
    }

    public String getZldwmc() {
        return zldwmc;
    }

    public void setZldwmc(String zldwmc) {
        this.zldwmc = zldwmc;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getPdm() {
        return pdm;
    }

    public void setPdm(String pdm) {
        this.pdm = pdm;
    }

    public String getCdm() {
        return cdm;
    }

    public void setCdm(String cdm) {
        this.cdm = cdm;
    }

    public Date getXmffsj() {
        return xmffsj;
    }

    public void setXmffsj(Date xmffsj) {
        this.xmffsj = xmffsj;
    }

    public String getXjxmjl() {
        return xjxmjl;
    }

    public void setXjxmjl(String xjxmjl) {
        this.xjxmjl = xjxmjl;
    }

    public String getSjxmjl() {
        return sjxmjl;
    }

    public void setSjxmjl(String sjxmjl) {
        this.sjxmjl = sjxmjl;
    }

    public String getSjbz() {
        return sjbz;
    }

    public void setSjbz(String sjbz) {
        this.sjbz = sjbz;
    }

    public String getSfqdghxy() {
        return sfqdghxy;
    }

    public void setSfqdghxy(String sfqdghxy) {
        this.sfqdghxy = sfqdghxy;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getXmbh() {
        return xmbh;
    }

    public void setXmbh(String xmbh) {
        this.xmbh = xmbh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public String getYsbh() {
        return ysbh;
    }

    public void setYsbh(String ysbh) {
        this.ysbh = ysbh;
    }

    public Integer getDkgs() {
        return dkgs;
    }

    public void setDkgs(Integer dkgs) {
        this.dkgs = dkgs;
    }

    public Integer getYjzdkgs() {
        return yjzdkgs;
    }

    public void setYjzdkgs(Integer yjzdkgs) {
        this.yjzdkgs = yjzdkgs;
    }

    public String getYswh() {
        return yswh;
    }

    public void setYswh(String yswh) {
        this.yswh = yswh;
    }

    public Date getYssj() {
        return yssj;
    }

    public void setYssj(Date yssj) {
        this.yssj = yssj;
    }

    public Float getXmjsgm() {
        return xmjsgm;
    }

    public void setXmjsgm(Float xmjsgm) {
        this.xmjsgm = xmjsgm;
    }

    public Float getXzgdmj() {
        return xzgdmj;
    }

    public void setXzgdmj(Float xzgdmj) {
        this.xzgdmj = xzgdmj;
    }

    public Float getXmzzj() {
        return xmzzj;
    }

    public void setXmzzj(Float xmzzj) {
        this.xmzzj = xmzzj;
    }

    public String getXmqfw() {
        return xmqfw;
    }

    public void setXmqfw(String xmqfw) {
        this.xmqfw = xmqfw;
    }

    public String getXjhcr() {
        return xjhcr;
    }

    public void setXjhcr(String xjhcr) {
        this.xjhcr = xjhcr;
    }

    public String getXjhczt() {
        return xjhczt;
    }

    public void setXjhczt(String xjhczt) {
        this.xjhczt = xjhczt;
    }

    public Date getXjhcsj() {
        return xjhcsj;
    }

    public void setXjhcsj(Date xjhcsj) {
        this.xjhcsj = xjhcsj;
    }

    public String getXjhcyj() {
        return xjhcyj;
    }

    public void setXjhcyj(String xjhcyj) {
        this.xjhcyj = xjhcyj;
    }

    public String getSjhczt() {
        return sjhczt;
    }

    public void setSjhczt(String sjhczt) {
        this.sjhczt = sjhczt;
    }

    public String getSjhcr() {
        return sjhcr;
    }

    public void setSjhcr(String sjhcr) {
        this.sjhcr = sjhcr;
    }

    public Date getSjhcsj() {
        return sjhcsj;
    }

    public void setSjhcsj(Date sjhcsj) {
        this.sjhcsj = sjhcsj;
    }

    public String getSjhcyj() {
        return sjhcyj;
    }

    public void setSjhcyj(String sjhcyj) {
        this.sjhcyj = sjhcyj;
    }

    public String getXmjzzt() {
        return xmjzzt;
    }

    public void setXmjzzt(String xmjzzt) {
        this.xmjzzt = xmjzzt;
    }

    public String getSfcxjz() {
        return sfcxjz;
    }

    public void setSfcxjz(String sfcxjz) {
        this.sfcxjz = sfcxjz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Float getJd() {
        return jd;
    }

    public void setJd(Float jd) {
        this.jd = jd;
    }

    public Float getWd() {
        return wd;
    }

    public void setWd(Float wd) {
        this.wd = wd;
    }

    public String getDkly() {
        return dkly;
    }

    public void setDkly(String dkly) {
        this.dkly = dkly;
    }
}

==> surveyplat-proof-common-nfzd-1.0.0-20211019.031030-14-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzXmxx.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2019/9/10
 * @description 增减挂钩项目信息表
 */
@Table(name = "dcjz_xmxx")
public class DcjzXmxx {
    //项目ID
    @Id
    private String xmid;
    //项目编号
    private String xmbh;
    //项目名称
    private String xmmc;
    //行政区代码
    private String xzqdm;
    //行政区名称
    private String xzqmc;
    //地块个数
    private Integer dkgs;
    //应举证地块个数
    private Integer yjzdkgs;
    //项目建设规模
    private Float xmjsgm;
    //新增耕地面积
    private Float xzgdmj;
    //项目总资金
    private Float xmzzj;
    //项目范围
    private String xmqfw;
    //项目举证状态
    private String xmjzzt;
    //是否重新举证
    private String sfcxjz;
    //备注
    private String bz;
    //项目分发时间
    private Date xmffsj;
    //省级代码
    private String pdm;
    //市级代码
    private String cdm;
    //地类代码
    private String dlbm;
    //地类名称
    private String dlmc;
    //坐落单位代码
    private String zldwdm;
    //坐落单位名称
    private String zldwmc;
    //权属性质
    private String qsxz;
    //是否摸排范围
    private String sfmpfw;
    //非摸排原因
    private String fmpyy;
    private Float jd;
    private Float wd;
    private String dkly;
    //县级核查人
    private String xjhcr;
    //县级核查状态
    private String xjhczt;
    //县级核查时间
    private Date xjhcsj;
    //县级核查意见
    private String xjhcyj;
    //市级核查状态
    private String cjhczt;
    //市级核查人
    private String cjhcr;
    //市级核查时间
    private Date cjhcsj;
    //市级核查意见
    private String cjhcyj;
    //省级核查状态
    private String sjhczt;
    //省级核查人
    private String sjhcr;
    //省级核查时间
    private Date sjhcsj;
    //省级核查意见
    private String sjhcyj;

    //镇级核查人
    private String zjhcr;
    //镇级核查状态
    private String zjhczt;
    //镇级核查时间
    private Date zjhcsj;
    //镇级核查意见
    private String zjhcyj;
    //镇级复查人
    private String zjfcr;
    //镇级复查状态
    private String zjfczt;
    //镇级复查时间
    private Date zjfcsj;
    //镇级复查意见
    private String zjfcyj;
    //县级复查人
    private String xjfcr;
    //县级复查状态
    private String xjfczt;
    //县级复查时间
    private Date xjfcsj;
    //县级复查意见
    private String xjfcyj;
    //市级复查人
    private String cjfcr;
    //市级复查状态
    private String cjfczt;
    //市级复查时间
    private Date cjfcsj;
    //市级复查意见
    private String cjfcyj;
    //省级复查状态
    private String sjfczt;
    //省级复查人
    private String sjfcr;
    //省级复查时间
    private Date sjfcsj;
    //省级复查意见
    private String sjfcyj;


    //退回节点 拼接记录退回级别，提交不清空
    private String thjd;

    //内业核查状态
    private String nyhczt;
    //内业核查人
    private String nyhcr;
    //内业核查时间
    private Date nyhcsj;
    //内业核查意见
    private String nyhcyj;
    //2013年之前建房
    private String sjjdzqjf;

    //重新举证原因
    private String cxjzyy;

    //核查意见代码
    private String nyhcyjdm;
    private String zjhcyjdm;
    private String zjfcyjdm;
    private String xjhcyjdm;
    private String xjfcyjdm;
    private String cjhcyjdm;
    private String cjfcyjdm;
    private String sjhcyjdm;
    private String sjfcyjdm;

    //退回记录 记录退回级别，提交清空
    private String thjl;
    //申请退回
    private String sqth;
    //项目来源 0：省级 1：国家发
    private String xmly;

    public String getSqth() {
        return sqth;
    }

    public void setSqth(String sqth) {
        this.sqth = sqth;
    }

    public String getXmly() {
        return xmly;
    }

    public void setXmly(String xmly) {
        this.xmly = xmly;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getXmbh() {
        return xmbh;
    }

    public void setXmbh(String xmbh) {
        this.xmbh = xmbh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public Integer getDkgs() {
        return dkgs;
    }

    public void setDkgs(Integer dkgs) {
        this.dkgs = dkgs;
    }

    public Integer getYjzdkgs() {
        return yjzdkgs;
    }

    public void setYjzdkgs(Integer yjzdkgs) {
        this.yjzdkgs = yjzdkgs;
    }

    public Float getXmjsgm() {
        return xmjsgm;
    }

    public void setXmjsgm(Float xmjsgm) {
        this.xmjsgm = xmjsgm;
    }

    public Float getXzgdmj() {
        return xzgdmj;
    }

    public void setXzgdmj(Float xzgdmj) {
        this.xzgdmj = xzgdmj;
    }

    public Float getXmzzj() {
        return xmzzj;
    }

    public void setXmzzj(Float xmzzj) {
        this.xmzzj = xmzzj;
    }

    public String getXmqfw() {
        return xmqfw;
    }

    public void setXmqfw(String xmqfw) {
        this.xmqfw = xmqfw;
    }

    public String getXmjzzt() {
        return xmjzzt;
    }

    public void setXmjzzt(String xmjzzt) {
        this.xmjzzt = xmjzzt;
    }

    public String getSfcxjz() {
        return sfcxjz;
    }

    public void setSfcxjz(String sfcxjz) {
        this.sfcxjz = sfcxjz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Date getXmffsj() {
        return xmffsj;
    }

    public void setXmffsj(Date xmffsj) {
        this.xmffsj = xmffsj;
    }

    public String getPdm() {
        return pdm;
    }

    public void setPdm(String pdm) {
        this.pdm = pdm;
    }

    public String getCdm() {
        return cdm;
    }

    public void setCdm(String cdm) {
        this.cdm = cdm;
    }

    public String getDlbm() {
        return dlbm;
    }

    public void setDlbm(String dlbm) {
        this.dlbm = dlbm;
    }

    public String getDlmc() {
        return dlmc;
    }

    public void setDlmc(String dlmc) {
        this.dlmc = dlmc;
    }

    public String getZldwdm() {
        return zldwdm;
    }

    public void setZldwdm(String zldwdm) {
        this.zldwdm = zldwdm;
    }

    public String getZldwmc() {
        return zldwmc;
    }

    public void setZldwmc(String zldwmc) {
        this.zldwmc = zldwmc;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getSfmpfw() {
        return sfmpfw;
    }

    public void setSfmpfw(String sfmpfw) {
        this.sfmpfw = sfmpfw;
    }

    public String getFmpyy() {
        return fmpyy;
    }

    public void setFmpyy(String fmpyy) {
        this.fmpyy = fmpyy;
    }

    public Float getJd() {
        return jd;
    }

    public void setJd(Float jd) {
        this.jd = jd;
    }

    public Float getWd() {
        return wd;
    }

    public void setWd(Float wd) {
        this.wd = wd;
    }

    public String getDkly() {
        return dkly;
    }

    public void setDkly(String dkly) {
        this.dkly = dkly;
    }

    public String getXjhcr() {
        return xjhcr;
    }

    public void setXjhcr(String xjhcr) {
        this.xjhcr = xjhcr;
    }

    public String getXjhczt() {
        return xjhczt;
    }

    public void setXjhczt(String xjhczt) {
        this.xjhczt = xjhczt;
    }

    public Date getXjhcsj() {
        return xjhcsj;
    }

    public void setXjhcsj(Date xjhcsj) {
        this.xjhcsj = xjhcsj;
    }

    public String getXjhcyj() {
        return xjhcyj;
    }

    public void setXjhcyj(String xjhcyj) {
        this.xjhcyj = xjhcyj;
    }

    public String getCjhczt() {
        return cjhczt;
    }

    public void setCjhczt(String cjhczt) {
        this.cjhczt = cjhczt;
    }

    public String getCjhcr() {
        return cjhcr;
    }

    public void setCjhcr(String cjhcr) {
        this.cjhcr = cjhcr;
    }

    public Date getCjhcsj() {
        return cjhcsj;
    }

    public void setCjhcsj(Date cjhcsj) {
        this.cjhcsj = cjhcsj;
    }

    public String getCjhcyj() {
        return cjhcyj;
    }

    public void setCjhcyj(String cjhcyj) {
        this.cjhcyj = cjhcyj;
    }

    public String getSjhczt() {
        return sjhczt;
    }

    public void setSjhczt(String sjhczt) {
        this.sjhczt = sjhczt;
    }

    public String getSjhcr() {
        return sjhcr;
    }

    public void setSjhcr(String sjhcr) {
        this.sjhcr = sjhcr;
    }

    public Date getSjhcsj() {
        return sjhcsj;
    }

    public void setSjhcsj(Date sjhcsj) {
        this.sjhcsj = sjhcsj;
    }

    public String getSjhcyj() {
        return sjhcyj;
    }

    public void setSjhcyj(String sjhcyj) {
        this.sjhcyj = sjhcyj;
    }

    public String getZjhcr() {
        return zjhcr;
    }

    public void setZjhcr(String zjhcr) {
        this.zjhcr = zjhcr;
    }

    public String getZjhczt() {
        return zjhczt;
    }

    public void setZjhczt(String zjhczt) {
        this.zjhczt = zjhczt;
    }

    public Date getZjhcsj() {
        return zjhcsj;
    }

    public void setZjhcsj(Date zjhcsj) {
        this.zjhcsj = zjhcsj;
    }

    public String getZjhcyj() {
        return zjhcyj;
    }

    public void setZjhcyj(String zjhcyj) {
        this.zjhcyj = zjhcyj;
    }

    public String getZjfcr() {
        return zjfcr;
    }

    public void setZjfcr(String zjfcr) {
        this.zjfcr = zjfcr;
    }

    public String getZjfczt() {
        return zjfczt;
    }

    public void setZjfczt(String zjfczt) {
        this.zjfczt = zjfczt;
    }

    public Date getZjfcsj() {
        return zjfcsj;
    }

    public void setZjfcsj(Date zjfcsj) {
        this.zjfcsj = zjfcsj;
    }

    public String getZjfcyj() {
        return zjfcyj;
    }

    public void setZjfcyj(String zjfcyj) {
        this.zjfcyj = zjfcyj;
    }

    public String getXjfcr() {
        return xjfcr;
    }

    public void setXjfcr(String xjfcr) {
        this.xjfcr = xjfcr;
    }

    public String getXjfczt() {
        return xjfczt;
    }

    public void setXjfczt(String xjfczt) {
        this.xjfczt = xjfczt;
    }

    public Date getXjfcsj() {
        return xjfcsj;
    }

    public void setXjfcsj(Date xjfcsj) {
        this.xjfcsj = xjfcsj;
    }

    public String getXjfcyj() {
        return xjfcyj;
    }

    public void setXjfcyj(String xjfcyj) {
        this.xjfcyj = xjfcyj;
    }

    public String getCjfcr() {
        return cjfcr;
    }

    public void setCjfcr(String cjfcr) {
        this.cjfcr = cjfcr;
    }

    public String getCjfczt() {
        return cjfczt;
    }

    public void setCjfczt(String cjfczt) {
        this.cjfczt = cjfczt;
    }

    public Date getCjfcsj() {
        return cjfcsj;
    }

    public void setCjfcsj(Date cjfcsj) {
        this.cjfcsj = cjfcsj;
    }

    public String getCjfcyj() {
        return cjfcyj;
    }

    public void setCjfcyj(String cjfcyj) {
        this.cjfcyj = cjfcyj;
    }

    public String getSjfczt() {
        return sjfczt;
    }

    public void setSjfczt(String sjfczt) {
        this.sjfczt = sjfczt;
    }

    public String getSjfcr() {
        return sjfcr;
    }

    public void setSjfcr(String sjfcr) {
        this.sjfcr = sjfcr;
    }

    public Date getSjfcsj() {
        return sjfcsj;
    }

    public void setSjfcsj(Date sjfcsj) {
        this.sjfcsj = sjfcsj;
    }

    public String getSjfcyj() {
        return sjfcyj;
    }

    public void setSjfcyj(String sjfcyj) {
        this.sjfcyj = sjfcyj;
    }

    public String getThjd() {
        return thjd;
    }

    public void setThjd(String thjd) {
        this.thjd = thjd;
    }
    public String getNyhczt() {
        return nyhczt;
    }

    public void setNyhczt(String nyhczt) {
        this.nyhczt = nyhczt;
    }

    public String getNyhcr() {
        return nyhcr;
    }

    public void setNyhcr(String nyhcr) {
        this.nyhcr = nyhcr;
    }

    public Date getNyhcsj() {
        return nyhcsj;
    }

    public void setNyhcsj(Date nyhcsj) {
        this.nyhcsj = nyhcsj;
    }

    public String getNyhcyj() {
        return nyhcyj;
    }

    public void setNyhcyj(String nyhcyj) {
        this.nyhcyj = nyhcyj;
    }

    public String getSjjdzqjf() {
        return sjjdzqjf;
    }

    public void setSjjdzqjf(String sjjdzqjf) {
        this.sjjdzqjf = sjjdzqjf;
    }

    public String getCxjzyy() {
        return cxjzyy;
    }

    public void setCxjzyy(String cxjzyy) {
        this.cxjzyy = cxjzyy;
    }

    public String getNyhcyjdm() {
        return nyhcyjdm;
    }

    public void setNyhcyjdm(String nyhcyjdm) {
        this.nyhcyjdm = nyhcyjdm;
    }

    public String getZjhcyjdm() {
        return zjhcyjdm;
    }

    public void setZjhcyjdm(String zjhcyjdm) {
        this.zjhcyjdm = zjhcyjdm;
    }

    public String getZjfcyjdm() {
        return zjfcyjdm;
    }

    public void setZjfcyjdm(String zjfcyjdm) {
        this.zjfcyjdm = zjfcyjdm;
    }

    public String getXjhcyjdm() {
        return xjhcyjdm;
    }

    public void setXjhcyjdm(String xjhcyjdm) {
        this.xjhcyjdm = xjhcyjdm;
    }

    public String getXjfcyjdm() {
        return xjfcyjdm;
    }

    public void setXjfcyjdm(String xjfcyjdm) {
        this.xjfcyjdm = xjfcyjdm;
    }

    public String getCjhcyjdm() {
        return cjhcyjdm;
    }

    public void setCjhcyjdm(String cjhcyjdm) {
        this.cjhcyjdm = cjhcyjdm;
    }

    public String getCjfcyjdm() {
        return cjfcyjdm;
    }

    public void setCjfcyjdm(String cjfcyjdm) {
        this.cjfcyjdm = cjfcyjdm;
    }

    public String getSjhcyjdm() {
        return sjhcyjdm;
    }

    public void setSjhcyjdm(String sjhcyjdm) {
        this.sjhcyjdm = sjhcyjdm;
    }

    public String getSjfcyjdm() {
        return sjfcyjdm;
    }

    public void setSjfcyjdm(String sjfcyjdm) {
        this.sjfcyjdm = sjfcyjdm;
    }

    public String getThjl() {
        return thjl;
    }

    public void setThjl(String thjl) {
        this.thjl = thjl;
    }
}
